/**
 * Simple example for controlling Sky box via USB 'sky controller'
 * 
 * Copyright (C) Joseph Heenan 2005-2007, all rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR `AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * $Id: sky-example.c,v 1.3 2007/05/14 12:24:29 joseph Exp $
 * 
 */

#include <stdio.h>
#include <stdlib.h>

#include "sky-control-lib.h"

#define USB_TIMEOUT 1000 /* milliseconds */

int main(void)
{
    sky_usb           *sky;
    
    if (sky_usb_initialise() != 0)
    {
        fprintf(stderr, "sky_usb_initalise failed\n");
        exit(EXIT_FAILURE);
    }

    sky = sky_usb_create(1 /*debug*/, USB_TIMEOUT);
    if (sky == NULL)
    {
        fprintf(stderr, "unable to create sky controller handle\n");
        exit(EXIT_FAILURE);
    }
        
    if (sky_usb_finddevice(sky, 0) != 0)
    {
        fprintf(stderr, "unable to find sky controller\n");
        exit(EXIT_FAILURE);
    }
    
    sky_usb_printinfo(sky);

    if (sky_usb_sendcommand(sky, 0 /* output 0 */,
                            0x0001 /* sky digit 1 */) != 0)
    {
        perror("sky_usb_sendcommand failed");
        return EXIT_FAILURE;
    }

    sky_usb_destroy(sky);
    
    sky_usb_finalise();
    
    return EXIT_SUCCESS;
}
